@@ -138,8 +138,8 @@ int main()
 
 	if(!compile_time::remote_repository())
 	{
-	    cerr << "MISSING LIBCURL SUPPORT TO BE ABLE TO PERFORM ALL TESTS, ABORTING" << endl;
-	    throw Efeature("libcurl");
+	    cerr << "MISSING LIBCURL or LIBSSH SUPPORT TO BE ABLE TO PERFORM ALL TESTS, ABORTING" << endl;
+	    throw Efeature("remote repositories");
 	}
 
 	if(!compile_time::ea())
