@@ -36,6 +36,9 @@ extern "C"
 #include "compile_time_features.hpp"
 #include "tools.hpp"
 #include "macro_tools.hpp"
+#include "user_interaction_blind.hpp"
+#include "generic_to_global_file.hpp"
+#include "tuyau_global.hpp"
 
 using namespace std;
 
@@ -71,6 +74,7 @@ namespace libdar
 	delta_sig = nullptr;
 	delta_sig_read = false;
 	read_ver = macro_tools_supported_version;
+	in_place.reset();
 
         try
         {
@@ -124,6 +128,7 @@ namespace libdar
 	delta_sig = nullptr;
 	delta_sig_read = false;
 	read_ver = reading_ver;
+	in_place.reset();
 
 	generic_file *ptr = nullptr;
 
@@ -345,6 +350,10 @@ namespace libdar
 	delta_sig = nullptr;
 	delta_sig_read = ref.delta_sig_read;
 	read_ver = ref.read_ver;
+	if(ref.in_place)
+	    in_place.reset(ref.in_place->clone_as_file());
+	else
+	    in_place.reset();
 
         try
         {
@@ -555,79 +564,96 @@ namespace libdar
 		}
 	    }
 
+	    if(status == from_patch)
+	    {
+		if(!in_place)
+		    throw SRC_BUG;
+
+		if(mode != normal)
+		    throw SRC_BUG;
+
+		if(delta_ref != nullptr)
+		    throw SRC_BUG;
+	    }
+
 		//
 
-	    if(status == from_path)
+	    switch(status)
 	    {
-		fichier_local *tmp = nullptr;
+	    case from_path:
 		if(mode != normal && mode != plain)
 		    throw SRC_BUG; // keep compressed/keep_hole is not possible on an inode take from a filesystem
-		ret = tmp = new (nothrow) fichier_local(chemin, furtive_read_mode);
-		try
+		else
 		{
-		    if(tmp != nullptr)
-			    // telling *tmp to flush the data from the cache as soon as possible
-			tmp->fadvise(fichier_global::advise_dontneed);
-		}
-		catch(Erange & e)
-		{
-			// silently ignoring fadvise related error,
-			// this is not crucial
-		}
-
-		if(delta_sig_mem || delta_ref)
-		{
-		    pile *data = new (nothrow) pile();
-		    if(data == nullptr)
-			throw Ememory("cat_file::get_data");
+		    fichier_local *tmp = nullptr;
+		    ret = tmp = new (nothrow) fichier_local(chemin, furtive_read_mode);
 		    try
 		    {
-			data->push(tmp);
+			if(tmp != nullptr)
+				// telling *tmp to flush the data from the cache as soon as possible
+			    tmp->fadvise(fichier_global::advise_dontneed);
 		    }
-		    catch(...)
+		    catch(Erange & e)
 		    {
-			delete data;
-			throw;
+			    // silently ignoring fadvise related error,
+			    // this is not crucial
 		    }
-		    ret = data;
 
-		    if(delta_sig_mem)
+		    if(delta_sig_mem || delta_ref)
 		    {
-			generic_rsync *delta = new (nothrow) generic_rsync(delta_sig_mem.get(), signature_block_size, data->top());
-			if(delta == nullptr)
+			pile *data = new (nothrow) pile();
+			if(data == nullptr)
 			    throw Ememory("cat_file::get_data");
 			try
 			{
-			    data->push(delta);
+			    data->push(tmp);
 			}
 			catch(...)
 			{
-			    delete delta;
+			    delete data;
 			    throw;
 			}
-		    }
+			ret = data;
 
-		    if(delta_ref)
-		    {
-			generic_rsync *diff = new (nothrow) generic_rsync(delta_ref.get(),
-									  data->top(),
-									  tools_file_size_to_crc_size(get_size()),
-									  checksum);
-			if(diff == nullptr)
-			    throw Ememory("cat_file::get_data");
-			try
+			if(delta_sig_mem)
 			{
-			    data->push(diff);
+			    generic_rsync *delta = new (nothrow) generic_rsync(delta_sig_mem.get(), signature_block_size, data->top());
+			    if(delta == nullptr)
+				throw Ememory("cat_file::get_data");
+			    try
+			    {
+				data->push(delta);
+			    }
+			    catch(...)
+			    {
+				delete delta;
+				throw;
+			    }
 			}
-			catch(...)
+
+			if(delta_ref)
 			{
-			    delete diff;
-			    throw;
+			    generic_rsync *diff = new (nothrow) generic_rsync(delta_ref.get(),
+									      data->top(),
+									      tools_file_size_to_crc_size(get_size()),
+									      checksum);
+			    if(diff == nullptr)
+				throw Ememory("cat_file::get_data");
+			    try
+			    {
+				data->push(diff);
+			    }
+			    catch(...)
+			    {
+				delete diff;
+				throw;
+			    }
 			}
 		    }
 		}
-	    }
-	    else // inode from archive
+		break;
+	    case from_cat:
+	    case from_patch:
 		if(get_pile() == nullptr)
 		    throw SRC_BUG; // set_archive_localisation never called or with a bad argument
 		else
@@ -745,7 +771,7 @@ namespace libdar
 				// normally having both delta_sig and sparse_file is excluded by sanity checks
 				// so we do not add delta_sig above sparse_file which would deserve sparse file
 				// detection (archive reading, restoration, testing, diffing, ...),
-				// but while merging we may have both sparse_file to provide plain file without hole
+				// but while merging we may have both: sparse_file to provide plain file without hole
 				// and generic_rsync to compute the delta signature of the plain file
 
 			    parent = data->is_empty() ? get_pile() : data->top();
@@ -766,6 +792,92 @@ namespace libdar
 				}
 			    }
 
+				// considering the case where we have to on-fly apply the patch (merging context)
+				// here too, this hides the copy_to() method of sparse_file [which itself overwites the default
+				// generic_file::copy_to(), adding skip() when a hole has to be restored],
+				// instead here the copy_to() method when applied to the object returned by get_data(),
+				// will be the one of the patcher in the stack, holes will be hidden and the sequence of zeroed
+				// bytes will be generated.
+				//
+				// we need to wrap the in_place data for the skip() operation performed on it by generic_rsync
+				// to be possible, as this cat_file may have a sparse_file at the top of the stack returned by
+				// get_data() which does not support skip() method on it.
+				// For that we will add a tuyau_global, and a generic_to_global_file, and keep these objects
+				// in the stack we return (for they can be memory released automatically with the patch data we
+				// provide: The stack view will thus be:
+				//
+				//  - generic_rsync (reads patch data and in_place data to provide patched file)
+			        //  - tuyau_global
+				//  - generic_to_global_file (to adapt tuyau global to the in_place::get_data()
+				//  - in_place->get_data(). This one does not rely on anything below in that stack
+				//  - [generic_rsync] (if deta_sig_mem is true, see just above), provides the patched data to the
+				//     generic_rsync located at the top of the stack
+			        //  -  [sparse_file]  (if sparse_file_detection_read() is true, see above)
+			        //  - compression layer from the archive object
+				//  - [escape layer] from the archive object layers
+			        //  - [encryption or caching] from the archive object layers
+			        //  - sar, trivial sar or zapette from the archive object layers
+
+			    parent = data->is_empty() ? get_pile() : data->top();
+
+			    if(status == from_patch)
+			    {
+				generic_file* to_be_patched;
+				shared_ptr<user_interaction_blind> dialog;
+				generic_to_global_file* ficglob = nullptr;
+				tuyau_global* pipe = nullptr;
+				shared_ptr<memory_file> unused;
+				generic_rsync *patcher = nullptr;
+
+				try
+				{
+				    to_be_patched = in_place->get_data(cat_file::plain,
+								       unused,
+								       0,
+								       unused,
+								       nullptr);
+				    if(to_be_patched == nullptr)
+					throw Ememory("cat_file::get_data()");
+
+				    dialog.reset(new (nothrow) user_interaction_blind());
+				    if(!dialog)
+					throw Ememory("cat_file::get_data()");
+
+				    ficglob = new (nothrow) generic_to_global_file(dialog,
+										   to_be_patched,
+										   gf_read_only);
+				    if(ficglob == nullptr)
+					throw Ememory("cat_file::get_data()");
+
+				    pipe = new (nothrow) tuyau_global(dialog, ficglob);
+				    if(pipe == nullptr)
+					throw Ememory("cat_file::get_data()");
+
+				    patcher = new (nothrow) generic_rsync(pipe,
+									  parent);
+				    if(patcher == nullptr)
+					throw Ememory("cat_file::get_data");
+
+				    data->push(to_be_patched);
+					// ficglob is under the responsibility of pipe and managed by it
+				    data->push(pipe);
+				    data->push(patcher);
+				}
+				catch(...)
+				{
+				    if(patcher != nullptr)
+					delete patcher;
+				    if(pipe != nullptr)
+					delete pipe;
+				    if(ficglob != nullptr)
+					delete ficglob;
+				    if(to_be_patched != nullptr)
+					delete to_be_patched;
+				    throw;
+				}
+			    }
+
+
 				// if the stack to return is empty adding a tronc
 				// to have the proper offset zero at the beginning of the data
 				//
@@ -803,6 +915,10 @@ namespace libdar
 			    throw;
 			}
 		    }
+		break;
+	    default:
+		throw SRC_BUG;
+	    }
 	}
 	catch(...)
 	{
@@ -834,11 +950,54 @@ namespace libdar
 	    if(get_compressor_layer() != nullptr)
 		get_compressor_layer()->suspend_compression();
 	    break;
+	case from_patch:
+	    me->in_place.reset();
+	    break;
 	default:
 	    throw SRC_BUG;
 	}
     }
 
+    bool cat_file::set_data_from_binary_patch(cat_file* in_place_addr)
+    {
+	    // do we have a patch?
+	if(get_saved_status() != saved_status::delta)
+	    return false;
+
+	    // is the in_place has data available?
+	if(in_place_addr == nullptr)
+	    return false;
+
+	if(in_place_addr->get_saved_status() != saved_status::saved)
+	    return false;
+	else
+	{
+	    const crc* data_crc = nullptr;
+	    const crc* base_crc = nullptr;
+
+	    // do in_place data matches CRC of our base CRC
+
+	    if(!in_place_addr->get_crc(data_crc))
+		return false;
+
+	    if(!get_patch_base_crc(base_crc))
+		return false;
+
+	    if(*data_crc != *base_crc)
+		return false;
+	}
+
+	    // record in_place address
+	in_place.reset(in_place_addr->clone_as_file());
+
+	    // modify our status
+	status = from_patch;
+	set_saved_status(saved_status::saved);
+
+	    // return appropriate value
+	return true;
+    }
+
     void cat_file::set_offset(const infinint & r)
     {
 	*offset = r;
@@ -871,7 +1030,16 @@ namespace libdar
 	if(get_escape_layer() == nullptr)
 	    if(check != nullptr)
 	    {
-		c = check;
+		if(status == from_patch)
+		{
+			// we return the expected CRC of the result
+			// as in this mode we provide the patched file
+			// not the data of the patch itself.
+		    if(!get_patch_result_crc(c))
+			throw SRC_BUG;
+		}
+		else
+		    c = check;
 		return true;
 	    }
 	    else
@@ -881,6 +1049,17 @@ namespace libdar
 	    if(get_saved_status() == saved_status::saved
 	       || get_saved_status() == saved_status::delta)
 	    {
+		if(status == from_patch)
+		{
+			// we return the expected CRC of the result
+			// as in this mode we provide the patched file
+			// not the data of the patch itself.
+		    if(!get_patch_result_crc(c))
+			throw SRC_BUG;
+
+		    return true;
+		}
+
 		if(check == nullptr)
 		{
 		    try
@@ -1259,12 +1438,19 @@ namespace libdar
 	clean_patch_base_crc();
     }
 
-    bool cat_file::same_data_as(const cat_file & other, bool check_data, const infinint & hourshift)
+    bool cat_file::same_data_as(const cat_file & other,
+				bool check_data,
+				const infinint & hourshift,
+				bool me_or_other_read_in_seq_mode)
     {
 	bool ret = true;
 	try
 	{
-	    sub_compare_internal(other, false, check_data, hourshift);
+	    sub_compare_internal(other,
+				 false,
+				 check_data,
+				 hourshift,
+				 me_or_other_read_in_seq_mode);
 	}
 	catch(Erange & e)
 	{
@@ -1273,15 +1459,18 @@ namespace libdar
 	return ret;
     }
 
-    void cat_file::sub_compare(const cat_inode & other, bool isolated_mode) const
+    void cat_file::sub_compare(const cat_inode & other,
+			       bool isolated_mode,
+			       bool seq_read_mode) const
     {
-	sub_compare_internal(other, !isolated_mode, true, 0);
+	sub_compare_internal(other, !isolated_mode, true, 0, seq_read_mode && isolated_mode);
     }
 
     void cat_file::sub_compare_internal(const cat_inode & other,
 					bool can_read_my_data,
 					bool can_read_other_data,
-					const infinint & hourshift) const
+					const infinint & hourshift,
+					bool seq_read_mode_and_isolated) const
     {
 	const cat_file *f_other = dynamic_cast<const cat_file *>(&other);
 	if(f_other == nullptr)
@@ -1399,7 +1588,7 @@ namespace libdar
 	    delete me;
 
 	}
-	else if(has_delta_signature_available()
+	else if(has_delta_signature_available() && ! seq_read_mode_and_isolated
 		&& (compile_time::librsync() || f_other->has_delta_signature_available()))
 	{
 		// calculate delta signature of file and comparing them
@@ -1464,7 +1653,7 @@ namespace libdar
 		drop_delta_signature_data();
 	    }
 	}
-	else // isolated_mode and no signature or no data
+	else // isolated_mode and no signature or no data or isolated_mode + seq_read_mode + signature
 	{
 	    const crc *my_crc = nullptr;
 
@@ -1569,5 +1758,15 @@ namespace libdar
 	clean_patch_base_crc();
     }
 
+    cat_file* cat_file::clone_as_file() const
+    {
+	cat_file* ret = new (nothrow) cat_file(*this);
+
+	if(ret == nullptr)
+	    throw Ememory("cat_file::clone_as_file");
+
+	return ret;
+    }
+
 
 } // end of namespace
