@@ -28,25 +28,27 @@ extern "C"
 #if HAVE_SYS_TYPES_H
 #include <sys/types.h>
 #endif
+
 #if HAVE_NETINET_IN_H
 #include <netinet/in.h>
 #endif
+
 #if HAVE_ARPA_INET_H
 #include <arpa/inet.h>
 #endif
-#ifdef STDC_HEADERS
+
+#ifdef HAVE_CTYPE_H
 #include <ctype.h>
 #endif
-#if TIME_WITH_SYS_TIME
-# include <sys/time.h>
+
+#if HAVE_TIME_H
 # include <time.h>
-#else
-# if HAVE_SYS_TIME_H
-# include <sys/time.h>
-# else
-# include <time.h>
-# endif
 #endif
+
+#if HAVE_SYS_TIME_H
+# include <sys/time.h>
+#endif
+
 #if HAVE_LIMITS_H
 #include <limits.h>
 #endif
@@ -384,7 +386,8 @@ namespace libdar
 			    const infinint & hourshift,
 			    bool symlink_date,
 			    const fsa_scope & scope,
-			    bool isolated_mode) const
+			    bool isolated_mode,
+			    bool seq_read_mode) const
     {
 	bool do_mtime_test = dynamic_cast<const cat_lien *>(&other) == nullptr || symlink_date;
 
@@ -417,7 +420,7 @@ namespace libdar
             throw Erange("cat_inode.compare", tools_printf(gettext("difference of last modification date: %S <--> %S"), &s1, &s2));
 	}
 
-        sub_compare(other, isolated_mode);
+        sub_compare(other, isolated_mode, seq_read_mode);
 
         switch(ea_get_saved_status())
         {
@@ -1443,15 +1446,15 @@ namespace libdar
 
     void cat_inode::move_from(cat_inode && ref) noexcept
     {
-	uid = move(ref.uid);
-	gid = move(ref.gid);
-	perm = move(ref.perm);
-	last_acc = move(ref.last_acc);
-	last_mod = move(ref.last_mod);
-	last_cha = move(ref.last_cha);
-	ea_saved = move(ref.ea_saved);
-	fsa_saved = move(ref.fsa_saved);
-	small_read = move(ref.small_read);
+	uid = std::move(ref.uid);
+	gid = std::move(ref.gid);
+	perm = std::move(ref.perm);
+	last_acc = std::move(ref.last_acc);
+	last_mod = std::move(ref.last_mod);
+	last_cha = std::move(ref.last_cha);
+	ea_saved = std::move(ref.ea_saved);
+	fsa_saved = std::move(ref.fsa_saved);
+	small_read = std::move(ref.small_read);
 	swap(ref.ea_offset, ea_offset);
 	swap(ref.ea, ea);
 	swap(ref.ea_size, ea_size);
@@ -1462,7 +1465,7 @@ namespace libdar
 	swap(ref.fsa_size, fsa_size);
 	swap(ref.fsa_crc, fsa_crc);
 	swap(ref.fs_dev, fs_dev);
-	edit = move(ref.edit);
+	edit = std::move(ref.edit);
     }
 
 
