@@ -129,6 +129,9 @@ namespace libdar
 	    // only directory may be read() twice.
 	virtual bool read_second_time_dir() const { return false; };
 
+	    /// return the <ROOT> based path of the current directory where reading is currently taking place
+	path get_current_read_path() const;
+
 
 	    // Additions methods. The addition is also iterative but uses its specific current_add directory pointer
 
@@ -175,14 +178,15 @@ namespace libdar
             // always return false, while it temporarily stores the missing directory structure
 
 
-
 	    // non-iterative methods:
 
 
 	    /// add into "this" detruit object corresponding to object of ref absent in "this"
 
 	    ///\note ref must have the same directory tree "this", else the operation generates an exception
-        infinint update_destroyed_with(const catalogue & ref);
+        infinint update_destroyed_with(const catalogue & ref,
+				       const path & fs_root,
+				       bool display_treated);
 
 
 	    /// copy from ref missing files in "this" and mark then as "not_saved" (no change since reference)
@@ -298,7 +302,7 @@ namespace libdar
     private :
         cat_directory *contenu;                   ///< catalogue contents
         mutable path out_compare;                 ///< stores the missing directory structure, when extracting
-        mutable cat_directory *current_compare;   ///< points to the current directory when extracting
+        mutable cat_directory *current_compare;   ///< points to the current directory when comparing
         mutable cat_directory *current_add;       ///< points to the directory where to add the next file with add_file;
         mutable cat_directory *current_read;      ///< points to the directory where the next item will be read
         path *sub_tree;                           ///< path to sub_tree
