@@ -83,7 +83,7 @@ namespace libdar
 		    case GPG_ERR_NO_ERROR:
 			break;
 		    default:
-			throw Erange("crypto_asym::encrypt", string(gettext("Unexpected error reported by GPGME: ")) + tools_gpgme_strerror_r(err));
+			throw Erange("crypto_asym::encrypt", string(gettext("Unexpected error reported by GPGME [gpgme_signers_clear()]: ")) + tools_gpgme_strerror_r(err));
 		    }
 		    ++ptr;
 		}
@@ -136,7 +136,7 @@ namespace libdar
 	    case GPG_ERR_UNUSABLE_PUBKEY:
 		throw Erange("crypto_asym::encrypt", gettext("Key found but users are not all trusted"));
 	    default:
-		throw Erange("crypto_asym::encrypt", string(gettext("Unexpected error reported by GPGME: ")) + tools_gpgme_strerror_r(err));
+		throw Erange("crypto_asym::encrypt", string(gettext("Unexpected error reported by GPGME [gpgme_op_encrypt[_sign]()]: ")) + tools_gpgme_strerror_r(err));
 	    }
 	}
 	catch(...)
@@ -172,7 +172,7 @@ namespace libdar
 	case GPG_ERR_BAD_PASSPHRASE:
 	    throw Erange("crypto_asym::decrypt", gettext("Failed retreiving passphrase"));
 	default:
-	    throw Erange("crypto_asym::decrypt", string(gettext("Unexpected error reported by GPGME: ")) + tools_gpgme_strerror_r(err));
+	    throw Erange("crypto_asym::decrypt", string(gettext("Unexpected error reported by GPGME [gpgme_op_decrypt_verify()]: ")) + tools_gpgme_strerror_r(err));
 	}
 #else
 	throw Ecompilation("Asymetric Strong encryption algorithms using GPGME");
@@ -231,7 +231,7 @@ namespace libdar
 		case GPG_ERR_INV_VALUE:
 		    throw SRC_BUG;
 		default:
-		    throw Erange("crypto_asym::decrypt", string(gettext("Unexpected error reported by GPGME: ")) + tools_gpgme_strerror_r(err));
+		    throw Erange("crypto_asym::decrypt", string(gettext("Unexpected error reported by GPGME [gpgme_op_keylist_start()]: ")) + tools_gpgme_strerror_r(err));
 		}
 
 		    // the the recipient string contains an '@' we assume we have
@@ -311,7 +311,7 @@ namespace libdar
 			}
 			break;
 		    default:
-			throw Erange("crypto_asym::decrypt", string(gettext("Unexpected error reported by GPGME: ")) + tools_gpgme_strerror_r(err));
+			throw Erange("crypto_asym::decrypt", string(gettext("Unexpected error reported by GPGME [gpgme_op_keylist_next()]: ")) + tools_gpgme_strerror_r(err));
 		    }
 		}
 		while(!found && !eof);
