@@ -23,7 +23,7 @@
 
 extern "C"
 {
-#if STDC_HEADERS
+#if HAVE_STDLIB_H
 #include <stdlib.h>
 #endif
 
@@ -445,6 +445,30 @@ namespace libdar
 	NLS_SWAP_OUT;
     }
 
+    void database::restore(const archive_options_read & read_options,
+			   const path & fs_root,
+			   const archive_options_extract & extract_options,
+			   const database_restore_options & opt,
+			   statistics* progressive_report)
+    {
+	NLS_SWAP_IN;
+	try
+	{
+	    pimpl->restore(read_options,
+			   fs_root,
+			   extract_options,
+			   opt,
+			   progressive_report);
+	}
+	catch(...)
+	{
+	    NLS_SWAP_OUT;
+	    throw;
+	}
+	NLS_SWAP_OUT;
+    }
+
+
     bool database::check_order() const
     {
 	bool ret;
