@@ -31,18 +31,8 @@ extern "C"
 #include <strings.h>
 #endif
 
-#if STDC_HEADERS
+#if HAVE_STRING_H
 # include <string.h>
-#else
-# if !HAVE_STRCHR
-#  define strchr index
-#  define strrchr rindex
-# endif
-    char *strchr (), *strrchr ();
-# if !HAVE_MEMCPY
-#  define memcpy(d, s, n) bcopy ((s), (d), (n))
-#  define memmove(d, s, n) bcopy ((s), (d), (n))
-# endif
 #endif
 
 } // end of extern "C"
