@@ -31,18 +31,8 @@ extern "C"
 #include <strings.h>
 #endif
 
-#if STDC_HEADERS
+#if HAVE_STRING_H
 # include <string.h>
-#else
-# if !HAVE_STRCHR
-#  define strchr index
-#  define strrchr rindex
-# endif
-    char *strchr (), *strrchr ();
-# if !HAVE_MEMCPY
-#  define memcpy(d, s, n) bcopy ((s), (d), (n))
-#  define memmove(d, s, n) bcopy ((s), (d), (n))
-# endif
 #endif
 
 #if HAVE_UNISTD_H
@@ -60,13 +50,10 @@ extern "C"
 #if HAVE_FCNTL_H
 #include <fcntl.h>
 #endif
-
-#if STDC_HEADERS
-#include <stdarg.h>
-#endif
 } // end extern "C"
 
 #include <iostream>
+#include <cstdarg>
 
 #include "user_interaction_callback.hpp"
 #include "erreurs.hpp"
